Struct luminance_std140::Aligned8 [−][src]
#[repr(C, align(8))]pub struct Aligned8<T>(pub T);Expand description
8-bytes aligned wrapper.
This wrapper type wraps its inner type on 8-bytes, allowing for fast encode/decode operations.
Tuple Fields
0: TTrait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more